@@ -89,7 +89,10 @@ def _label(definition):
 
 
 def _detail(definition):
-    return definition.parent().full_name or ''
+    try:
+        return definition.parent().full_name or ''
+    except AttributeError:
+        return definition.full_name or ''
 
 
 def _sort_text(definition):
